# - Find Elektra
#
# Find the native Elektra headers and libraries:
#
#  ELEKTRA_FOUND         - True if Elektra found.
#  ELEKTRA_INCLUDE_DIRS  - where to find kdb.h, etc.
#  ELEKTRA_LIBRARIES     - List of libraries when using Elektra.
#
#
# Find the kdb tools:
#
#  ELEKTRA_KDB_FOUND     - True if KDB TOOL found.
#  ELEKTRA_KDB_GEN_FOUND - True if KDB GEN TOOL found
#  ELEKTRA_TEMPLATES     - Folder where to find templates for kdb gen
#
#
# For version information see:
#
#  ELEKTRA_VERSION       - The version of elektra (x.y.z)
#  ELEKTRA_VERSION_MAJOR - The major version of elektra (x)
#  ELEKTRA_VERSION_MINOR - The minor version of elektra (y)
#  ELEKTRA_VERSION_MICRO - The patch version of elektra (z)
#



# Set path to the header file.
FIND_PATH(ELEKTRA_INCLUDE_DIR
	NAMES kdb.h
	PATHS /usr/include/elektra
	NO_DEFAULT_PATH
)
MARK_AS_ADVANCED(ELEKTRA_INCLUDE_DIR)


# Set path to the library.
FIND_LIBRARY(ELEKTRA_LIBRARY
	NAMES elektra elektra-full elektra-static
	PATHS /usr/lib/arm-linux-gnueabi
	NO_DEFAULT_PATH
)
MARK_AS_ADVANCED(ELEKTRA_LIBRARY)

FIND_PATH(ELEKTRA_TEMPLATES
	NAMES template.h
	PATHS /usr/share/elektra/templates
	NO_DEFAULT_PATH
)

# handle the QUIETLY and REQUIRED arguments and set ELEKTRA_FOUND to TRUE if
# all listed variables are TRUE
INCLUDE(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(Elektra DEFAULT_MSG ELEKTRA_LIBRARY ELEKTRA_INCLUDE_DIR)

if (ELEKTRA_FOUND)
	set (ELEKTRA_VERSION 0.8.7)
	set (ELEKTRA_VERSION_MAJOR 0)
	set (ELEKTRA_VERSION_MINOR 8)
	set (ELEKTRA_VERSION_MICRO 7)

	SET(ELEKTRA_INCLUDE_DIRS ${ELEKTRA_INCLUDE_DIR})
	SET(ELEKTRA_LIBRARIES    ${ELEKTRA_LIBRARY})
endif (ELEKTRA_FOUND)
